package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.ShipDynamicsMapper;
import com.steerinfo.dil.mapper.TmsshipControlLineMapper;
import com.steerinfo.dil.model.TmsshipControlLine;
import com.steerinfo.dil.service.IShipDynamicsService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class ShipDynamicsServiceImpl implements IShipDynamicsService {
    @Autowired
    ShipDynamicsMapper shipDynamicsMapper;

    @Autowired
    TmsshipControlLineMapper tmsshipControlLineMapper;

    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    //获取视图里的所有外轮船名，物资名称
    public List<Map<String, Object>> selectAll(Map<String,Object> map) {
        return shipDynamicsMapper.selectAll(map);
    }



    @Override
    public List<Map<String, Object>> selectByshipName(String shipName, String materialName) {
        return shipDynamicsMapper.selectByshipName(shipName,materialName);
    }

    @Override
    public List<Map<String, Object>> getLoadData(Map<String,Object> map){
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        return shipDynamicsMapper.getLoadData(map);
    }

    @Override
    public List<Map<String, Object>> getUnloadData(Map<String,Object> map){
        List<Map<String, Object>> list=new ArrayList<>();
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        list.addAll(shipDynamicsMapper.getUnloadData(map));
        list.addAll(shipDynamicsMapper.getLocationData(map));
        boolean f1=false,f2=false,f3=false;
        for(Map<String, Object> temp:list){
            switch (temp.get("status").toString()){
                case "已卸船数":
                    f1=true;
                    break;
                case "待卸船数":
                    f2=true;
                    break;
                case "在卸船数":
                    f3=true;
                    break;
            }
        }
        if(!f1){
            Map<String, Object> m=new HashMap<>();
            m.put("status","已卸船数");
            m.put("num",0);
            list.add(m);
        }
        if(!f2){
            Map<String, Object> m=new HashMap<>();
            m.put("status","待卸船数");
            m.put("num",0);
            list.add(m);
        }
        if(!f3){
            Map<String, Object> m=new HashMap<>();
            m.put("status","在卸船数");
            m.put("num",0);
            list.add(m);
        }
        return list;
    }

    @Override
    public List<Map<String, Object>> getDownShipDynamaics(Map<String,Object> map){
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        return shipDynamicsMapper.getDownShipDynamaics(map);
    }

    @Override
    public List<Map<String, Object>> getWagonWork(Map<String, Object> map) {
        String startTime=map.get("startTime")+"";
        String endTime=map.get("endTime")+"";
        DataChange.queryDataByDateTime(startTime, endTime, map, sdfDateTime);//根据时间段查询数据
        //把当月时间放进去
        SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM");
        String monthDate = sdfDate.format(new Date());
        map.put("monthDate",monthDate);
        List<Map<String,Object>> list=new ArrayList<>();
        //分别加到里面
        Map<String,Object> pleaseData= shipDynamicsMapper.getPleaseData(map);
        Map<String,Object> map1=new HashMap<>(),map2=new HashMap<>(),map3=new HashMap<>();
        map1.put("dateType","点前剩余计划");
        map2.put("dateType","当日批复计划");
        if(pleaseData!=null){
            map1.put("num",pleaseData.get("surplusSum"));
            map2.put("num",pleaseData.get("approveSum"));
        }else{
            map1.put("num",0);
            map2.put("num",0);
        }
        map3.put("dateType","月累计装车量");
        map3.put("num",shipDynamicsMapper.getRealNumberMonth(map));
        list.add(map1);
        list.add(map2);
        list.add(map3);
        return list;
    }

    @Override
    public List<Map<String, Object>> getControlLines(Map<String, Object> map) {
        int year=Integer.parseInt(map.get("year").toString());
        int month=Integer.parseInt(map.get("month").toString());
        String time=""+year+"-";
        if(month<10 && month > 0){
            time+="0";
        }
        time+=month;
        map.put("time",time);
        List<Map<String,Object>> list = tmsshipControlLineMapper.getControlLines(map);
        if(list==null || list.size()<=0) {
            //查不到年月的数据，新增
            TmsshipControlLine line = new TmsshipControlLine();
            line.setUp((short) 0);
            line.setDown((short) 0);
            line.setCount((short) 0);
            for (Date temp : getMonthFullDay(year, month)) {
                line.setResultId(tmsshipControlLineMapper.selectMaxId());
                line.setLineDate(temp);
                tmsshipControlLineMapper.insertSelective(line);
            }
            return tmsshipControlLineMapper.getControlLines(map);
        }
        return list;
    }

    @Override
    public int updateControlLine(TmsshipControlLine result) {
        return tmsshipControlLineMapper.updateByPrimaryKeySelective(result);
    }

    @Override
    public List<List<Map<String, Object>>> getControlLinesTable(Map<String, Object> map) {
        int year=Integer.parseInt(map.get("year").toString());
        int month=Integer.parseInt(map.get("month").toString());
        List<List<Map<String, Object>>> result=new ArrayList<>();
        map.put("time",previousMonth(year,month,0));//当月
        List<Map<String,Object>> list1 = tmsshipControlLineMapper.getControlLines(map);
        map.put("time",previousMonth(year,month,1));//上一个月
        List<Map<String,Object>> list2 = tmsshipControlLineMapper.getControlLines(map);
        map.put("time",previousMonth(year,month,2));//上上个月
        List<Map<String,Object>> list3 = tmsshipControlLineMapper.getControlLines(map);
        map.put("time",previousMonth(year,month,3));//上上上月
        List<Map<String,Object>> list4 = tmsshipControlLineMapper.getControlLines(map);
        result.add(list4);
        result.add(list3);
        result.add(list2);
        result.add(list1);
        return result;
    }

    public List<Date> getMonthFullDay(int year, int month) {
        List<String> fullDayList = new ArrayList<String>();
        List<Date> fullDateList= new ArrayList<Date>();
        int day = 1;// 所有月份从1号开始
        Calendar cal = Calendar.getInstance();// 获得当前日期对象
        cal.clear();// 清除信息
        cal.set(Calendar.YEAR, year);
        cal.set(Calendar.MONTH, month - 1);// 1月从0开始
        cal.set(Calendar.DAY_OF_MONTH, day);
        int count = cal.getActualMaximum(Calendar.DAY_OF_MONTH);//获取当前月份最大天数
        for (int j = 0; j <= (count - 1); ) {
            if (sdfDateTime.format(cal.getTime()).equals(getLastDay(year, month)))
                break;
            cal.add(Calendar.DAY_OF_MONTH, j == 0 ? +0 : +1);
            j++;
            fullDayList.add(sdfDateTime.format(cal.getTime()));
            fullDateList.add(cal.getTime());
        }
        //return fullDayList;
        return fullDateList;
    }

    public String getLastDay(int year, int month) {
        Calendar cal = Calendar.getInstance();
        cal.set(Calendar.YEAR, year);
        cal.set(Calendar.MONTH, month);
        cal.set(Calendar.DAY_OF_MONTH, 0);
        return sdfDateTime.format(cal.getTime());
    }

    public String previousMonth(int year, int month,int number){
        if(month-number<=0){
            year--;
            month=12+month-number;
        }else{
            month-=number;
        }
        String time=""+year+"-";
        if(month<10 && month > 0){
            time+="0";
        }
        time+=month;
        return time;
    }
}
